@@ -37,8 +37,10 @@ sub get_transport {
     $scheme =~s{ \A ([^\:]+) \: .+ }{$1}smx;
 
     if ($registered_transport_of{ $scheme }) {
-        eval "require $registered_transport_of{ $scheme }"
-            or die "Cannot load transport class $registered_transport_of{ $scheme } : $@";
+        no strict qw(refs);
+        *{ $registered_transport_of{ $scheme } . '::' }{ CODE }
+            or eval "require $registered_transport_of{ $scheme }"
+                or die "Cannot load transport class $registered_transport_of{ $scheme } : $@";
 
         # try "foo::Client" class first - SOAP::Tranport always requires
         # a package withoug the ::Client appended, and then
@@ -68,8 +70,10 @@ sub get_transport {
     }
 
     if (exists $SOAP_WSDL_TRANSPORT_OF{ $scheme }) {
-        eval "require $SOAP_WSDL_TRANSPORT_OF{ $scheme }"
-            or die "Cannot load transport class $SOAP_WSDL_TRANSPORT_OF{ $scheme } : $@";
+        no strict qw(refs);
+        *{ $SOAP_WSDL_TRANSPORT_OF{ $scheme } . '::' }{ CODE } 
+            or eval "require $SOAP_WSDL_TRANSPORT_OF{ $scheme }"
+                or die "Cannot load transport class $SOAP_WSDL_TRANSPORT_OF{ $scheme } : $@";
         return $SOAP_WSDL_TRANSPORT_OF{ $scheme }->new( %attrs );
     }
 
@@ -236,9 +240,9 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 427 $
+ $Rev: 435 $
  $LastChangedBy: kutterma $
- $Id: Transport.pm 427 2007-12-02 22:20:24Z kutterma $
+ $Id: Transport.pm 435 2007-12-03 22:31:00Z kutterma $
  $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Factory/Transport.pm $
  
 =cut
