@@ -1,7 +1,7 @@
 package SOAP::WSDL::Message;
 use strict;
 use warnings;
-use Class::Std::Storable;
+use Class::Std::Fast::Storable;
 use base qw(SOAP::WSDL::Base);
 
 my %part_of :ATTR(:name<part> :default<[]>);
