@@ -1,9 +1,7 @@
 package SOAP::WSDL::SOAP::Address;
 use strict;
 use warnings;
-use Class::Std::Storable;
 use base qw(SOAP::WSDL::Base);
-
-
+use Class::Std::Fast::Storable;
 my %location   :ATTR(:name<location> :default<()>);
 1;
\ No newline at end of file
